@@ -30,6 +30,7 @@ import os
 import sys
 import socket, ssl
 from subprocess import *
+import textwrap
 #from xml.dom.ext import *
 #from xml.dom.minidom import Document, parse
 import time
@@ -291,7 +292,16 @@ class IMGenerate(object):
     
         return output
 
-    
+def extra_help():
+   msg = "Useful information about the software. Currently, we do not parse the packages names provided within the -s/--software option" +\
+         "Therefore, if some package name is wrong, it won't be installed. Here we provide a list of useful packages names from the official repositories: \n" +\
+         "CentOS: mpich2, python26, java-1.6.0-openjdk. More packages names can be found in http://mirror.centos.org/ \n" +\
+         "Ubuntu: mpich2, openjdk-6-jre, openjdk-6-jdk. More packages names can be found in http://packages.ubuntu.com/ \n\n" +\
+         "FutureGrid Performance packages (currently only for CentOS 5): fg-intel-compilers, intel-compilerpro-common, " +\
+         "intel-compilerpro-devel, intel-compilerproc, intel-compilerproc-common, intel-compilerproc-devel " +\
+         "intel-compilerprof, intel-compilerprof-common, intel-compilerprof-devel, intel-openmp, intel-openmp-devel, openmpi-intel"
+   return msg
+   
 def main():
 
     #Default params
@@ -310,11 +320,12 @@ def main():
     #fedora-distro = ['14','12']
 
     parser = argparse.ArgumentParser(prog="fg-generate", formatter_class=argparse.RawDescriptionHelpFormatter,
-                                     description="FutureGrid Image Generation Help")    
+                                     description="FutureGrid Image Generation Help",
+                                     epilog=textwrap.dedent(extra_help()))    
     parser.add_argument('-u', '--user', dest='user', required=True, help='FutureGrid User name')
     parser.add_argument('-d', '--debug', dest='debug', action="store_true", help='Print logs in the screen for debug')
     parser.add_argument("-o", "--os", dest="OS", required=True, metavar='OSName', help="Specify the desired Operating System for the new image. Currently, Centos and Ubuntu are supported")
-    parser.add_argument("-v", "--version", dest="version", metavar='OSversion', help="Operating System version. In the case of Centos, it can be 5 or 6. In the case of Ubuntu, it can be karmic(9.10), lucid(10.04), maverick(10.10), natty (11.04)")
+    parser.add_argument("-v", "--version", dest="version", metavar='OSversion', help="Operating System version. In the case of Centos, it can be 5 or 6. In the case of Ubuntu, it can be karmic(9.10), lucid(10.04), maverick(10.10), natty (11.04), oneiric (11.10), precise (12.04)")
     parser.add_argument("-a", "--arch", dest="arch", metavar='arch', help="Destination hardware architecture")
     group1 = parser.add_mutually_exclusive_group()
     group1.add_argument("--baseimage", dest="baseimage", default=False, action="store_true", help="Generate a Base Image that will be used to generate other images. In this way, the image generation process will be faster.")    
@@ -340,9 +351,16 @@ def main():
     else:        
         passwd = "None"
     
-    if args.size < 1.5:
-        args.size=1.5
-    
+    try:
+        temp=float(args.size)
+        if temp < 1.5:
+            args.size=1.5
+        else:
+            args.size=temp
+    except ValueError:
+        print "The size has to be a number"
+        sys.exit(1)
+   
     arch = "x86_64" #Default to 64-bit
 
     #Parse arch command line arg
@@ -363,7 +381,7 @@ def main():
     OS = ""
     if args.OS == "Ubuntu" or args.OS == "ubuntu":
         OS = "ubuntu"
-        supported_versions = ["karmic", "lucid", "maverick", "natty"]
+        supported_versions = ["karmic", "lucid", "maverick", "natty", "oneiric","precise"]
         if type(args.version) is NoneType:
             version = default_ubuntu
         elif args.version == "9.10" or args.version == "karmic":
@@ -374,6 +392,10 @@ def main():
             version = "maverick"
         elif args.version == "11.04" or args.version == "natty":
             version = "natty"
+        elif args.version == "11.10" or args.version == "oneiric":
+            version = "oneiric"
+        elif args.version == "12.04" or args.version == "precise":
+            version = "precise"
         else:
             print "ERROR: Incorrect OS version specified. Supported OS version for " + OS + " are " + str(supported_versions)
             sys.exit(1)
