@@ -177,9 +177,11 @@ class IMGenerateServer(object):
                 self.logger.info("Image Generation Request DONE")
             except:
                 self.logger.error("Uncontrolled Error: " + str(sys.exc_info()))
-                if type(connstream) is ssl.SSLSocket: 
+                try: 
                     connstream.shutdown(socket.SHUT_RDWR)
-                    connstream.close() 
+                    connstream.close()
+                except:
+                    pass 
                 self.logger.info("Image Generation Request DONE")
                 
                   
@@ -435,6 +437,7 @@ class IMGenerateServer(object):
                     start = time.time()
                     
                     uid = self._rExec(self.rootId, cmdexec, vmaddr)
+                    self.logger.debug("Returned from script execution" +str(uid))
                     
                     end = time.time()
                     self.logger.info('TIME generate image:' + str(end - start))
@@ -443,8 +446,8 @@ class IMGenerateServer(object):
                     cmdscp = "scp -q -oBatchMode=yes " + self.rootId + "@" + vmaddr + ":/root/fg-image-generate.log " + self.tempdirserver + "/" + str(vmID) + "_gen.log"
                     os.system(cmdscp)
                     
-                    status = uid[0].strip() #it contains error or filename
-                    if status == "error":
+                    status = uid[0].strip() #it contains error or filename                    
+                    if "error" in uid:
                         msg = "ERROR: " + str(uid[1])
                         self.errormsg(channel, msg)
                     else:
@@ -808,10 +811,7 @@ class IMGenerateServer(object):
         outputs = f.readlines()
         f.close()
         os.system("rm -f " + tmpFile)
-        #output = ""
-        #for line in outputs:
-        #    output += line.strip()
-        #print outputs
+        
         return outputs
     
 def main():
