@@ -100,6 +100,29 @@ class IRServiceProxy(object):
         except:            
             self._log.debug("In disconnect:" + str(sys.exc_info()))
     
+    def isUserAdmin(self, userId, passwd, userIdB):
+        """
+        return True or False
+        """
+        start = time.time()
+        
+        checkauthstat = []
+        output = None
+        msg = userId + "|" + str(passwd) + "|" + self.passwdtype + "|isUserAdmin|" + userIdB
+        self._connIrServer.write(msg)
+        authstatus=self.check_auth(userId, checkauthstat)
+        if authstatus == True:
+            #wait for output
+            output = eval(self._connIrServer.read(1024))            
+        else:
+            output=str(checkauthstat[1])
+            self._log.error(str(checkauthstat[0]))
+                    
+        end = time.time()
+        self._log.info('TIME query:' + str(end - start))
+        
+        return output
+    
     def getUserStatus(self, userId, passwd, userIdB): #this is used by other services to check the status of the user before checking passwd in ldap
         """
         return "Active", "NoActive" or "NoUser"
@@ -188,7 +211,13 @@ class IRServiceProxy(object):
         self._connIrServer.write(msg)
         if self.check_auth(userId, checkauthstat):
             #wait for output
-            output = self._connIrServer.read(32768)            
+            data = self._connIrServer.read(32768)
+            if data:
+                output = str(data)            
+            while data:
+                data = self._connIrServer.read(32768)
+                if data:
+                    output += str(data)            
             if output == "None":
                 output = None
         else:
@@ -288,6 +317,7 @@ class IRServiceProxy(object):
                     imgId = output[1]
                     fileLocation = imgStore + imgId
                     self._log.info("Uploading the image")
+                    os.system("chmod +r " + imgFile)
                     if self.verbose:
                         print 'Uploading image. You may be asked for ssh/passphrase password'
                         cmd = 'scp ' + imgFile + " " + \
@@ -496,7 +526,14 @@ class IRServiceProxy(object):
         self._connIrServer.write(msg)
         if self.check_auth(userId, checkauthstat):
             #wait for output
-            output = self._connIrServer.read(32768)
+            data = self._connIrServer.read(32768)
+            if data:
+                output = str(data)            
+            while data:
+                data = self._connIrServer.read(32768)
+                if data:
+                    output += str(data)
+                
             if output == "None":
                 output = None
         else:
@@ -629,7 +666,13 @@ class IRServiceProxy(object):
         self._connIrServer.write(msg)
         if self.check_auth(userId, checkauthstat):
             #wait for output
-            output = self._connIrServer.read(32768)
+            data = self._connIrServer.read(32768)
+            if data:
+                output = str(data)            
+            while data:
+                data = self._connIrServer.read(32768)
+                if data:
+                    output += str(data)
             if output == "None":
                 output = None
         else:
@@ -660,7 +703,13 @@ class IRServiceProxy(object):
         self._connIrServer.write(msg)
         if self.check_auth(userId, checkauthstat):
             #wait for output
-            output = self._connIrServer.read(32768)
+            data = self._connIrServer.read(32768)
+            if data:
+                output = str(data)            
+            while data:
+                data = self._connIrServer.read(32768)
+                if data:
+                    output += str(data)
             if output == "None":
                 output = None
         else:
