@@ -40,7 +40,7 @@ import hashlib
 from futuregrid.utils.fgLog import fgLog
 from futuregrid.shell.fgShellUtils import fgShellUtils
 from futuregrid.shell.fgShellRepo import fgShellRepo
-from futuregrid.shell.fgShellHadoop import fgShellHadoop
+#from futuregrid.shell.fgShellHadoop import fgShellHadoop
 from futuregrid.shell.fgShellRain import fgShellRain
 from futuregrid.shell.fgShellConf import fgShellConf
 from futuregrid.shell.fgShellImage import fgShellImage
@@ -50,7 +50,6 @@ from futuregrid.utils.FGTypes import FGCredential
 class fgShell(fgShellUtils,
               Cmd,
               fgShellRepo,
-              fgShellHadoop,
               fgShellRain,
               fgShellImage):
 
@@ -136,11 +135,11 @@ class fgShell(fgShellUtils,
         fgShellUtils.__init__(self)        
 
         #Context        
-        self.env = ["repo", "hadoop", "image", "rain", ""]
+        self.env = ["repo", "image", "rain", ""] 
         self.text = {'image': 'Image Management',
                      'repo':'Image Repository',
-                     'rain':'FG Dynamic Provisioning',
-                     'hadoop':'Apache Hadoop'}
+                     'rain':'FG Dynamic Provisioning'}
+                     
         self._use = ""
         self._requirements = []
         self._contextOn = [] # initialized contexts
@@ -159,7 +158,8 @@ class fgShell(fgShellUtils,
             self.intro = self.loadBanner()
         ##Load History
         self.loadhist("no argument needed")
-        #e = sysCheck()        
+        #e = sysCheck()
+        self.do_use("rain")        
     
 
     #TODO: GVL: Do wer realy need that method, its just from the original cmd2 code. I commented it out.
@@ -242,8 +242,6 @@ class fgShell(fgShellUtils,
 
             if (arg == "repo"):                
                 self._requirements = ["Repo"]
-            elif (arg == "hadoop"):
-                self._requirements = ["Hadoop"]
             elif (arg == "rain"):
                 self._requirements = ["Rain", "Repo", "Image"]#,"Gene","Rain"] #rain context requires initialize repo and generation
             elif (arg == "image"):
@@ -606,8 +604,10 @@ class fgShell(fgShellUtils,
             allspec_aux = []
             allundoc = []
             for i in self._requirements:
-                undoc_header = "Undocumented commands in the " + string.lower(i) + " context (type help <topic>):"
-                specdoc_header = "Specific documented commands in the " + string.lower(i)  + " context (type help <topic>):"                
+                bold = "\033[1m"
+                reset = "\033[0;0m"
+                undoc_header = "Undocumented commands in the " + bold + string.lower(i) + reset + " context (type help <topic>):"
+                specdoc_header = "Specific documented commands in the " + bold + string.lower(i) + reset + " context (type help <topic>):"                
                 cmd.Cmd.print_topics(self, specdoc_header, allspec[string.lower(i)], 15, 80)
                 #cmd.Cmd.print_topics(self,cmd.Cmd.misc_header, help.keys(), 15,80)
                 cmd.Cmd.print_topics(self, undoc_header, undoc[string.lower(i)], 15, 80)
