@@ -155,9 +155,11 @@ class fgShellUtils(Cmd):
                     pass
         
         for cntxt in self.env:            
-            if (cntxt.strip() != ""):                
+            if (cntxt.strip() != ""):    
+                bold = "\033[1m"
+                reset = "\033[0;0m"            
                 print "######################################################################"
-                print "\nSpecific Commands for the context: " + cntxt
+                print "\nSpecific Commands for the context: " + bold + cntxt + reset
                 print "######################################################################"
 
                 self.getDocUndoc(cntxt)
@@ -250,10 +252,12 @@ class fgShellUtils(Cmd):
         self.generic_error()
 
 
+        
+    """
+    This was for the old hadoop that now is integrated in Rain    
     #################################
     #Run JOB
-    #################################    
-
+    #################################
     def do_runjob(self, args):
         '''run the job'''
         if(self._use != ""):            
@@ -299,7 +303,8 @@ class fgShellUtils(Cmd):
             self.generic_error()
 
     help_runjob = generic_help
-
+    """
+    
     #################################
     #GET
     #################################
@@ -592,6 +597,26 @@ class fgShellUtils(Cmd):
             self.generic_error()
     help_register = generic_help
 
+    def do_deregister(self, args):
+
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "deregister(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no deregister method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_register = generic_help
+
     #################################
     #Generate image
     #################################
@@ -638,6 +663,28 @@ class fgShellUtils(Cmd):
             self.generic_error()
     help_launch = generic_help
 
+    def do_launchhadoop(self, args):
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                print prefix
+                
+                command = "self.do_" + prefix + "launchhadoop(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    print str(sys.exc_info())
+                    pass
+            if not found:
+                print "There is no launchhadoop method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_launchhadoop = generic_help
+
     def do_hpclist(self, args):        
         if(self._use != ""):
             found = False
@@ -715,6 +762,102 @@ class fgShellUtils(Cmd):
             self.generic_error()
     help_cloudlistkernels = generic_help
     
+    def do_listsites(self, args):        
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "listsites(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no listsites method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_cloudlistkernels = generic_help
+
+
+    def do_cloudinstancesterminate(self, args):        
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "cloudinstancesterminate(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no cloudinstancesterminate method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_terminatecloudinstances = generic_help
+    
+    def do_hpcjobsterminate(self, args):        
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "hpcjobsterminate(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no hpcjobsterminate method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_terminatehpcjobs = generic_help
+    
+    def do_cloudinstanceslist(self, args):        
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "cloudinstanceslist(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no cloudinstanceslist method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_listcloudinstances = generic_help
+    
+    def do_hpcjobslist(self, args):        
+        if(self._use != ""):
+            found = False
+            for i in self._requirements:
+                prefix=string.lower(i)
+                command = "self.do_" + prefix + "hpcjobslist(\"" + args + "\")"            
+                try:
+                    eval(command)
+                    found = True
+                    break
+                except AttributeError:
+                    pass
+            if not found:
+                print "There is no hpcjobslist method in any of the active contexts (" + str(self._requirements) + " )"
+                self._log.error(str(sys.exc_info()))         
+        else:
+            self.generic_error()
+    help_listhpcjobs = generic_help
+    
 
     ##########################################################################
     # LOAD
